#!/bin/bash
#
# Multi-user mode
#
# Mostly written by Lasse Collin.
# Contains code and comments written by Patrick Volkerding.
#
# Last modified: 2006-01-29

# Set the basic environment (including PATH) expected by boot scripts.
[[ ! $HAVE_RC_FUNCTIONS ]] && . /etc/rc.d/rc.functions --keep-environment

# udevd needs to restarted when coming back from single user mode.
pgrep -x -U 0 -G 0 udevd &> /dev/null || ( . /etc/rc.d/rc.udev start )

# Retrigger failed events. There can be failed events if something
# couldn't be done when root file system was read-only and other file
# systems weren't mounted, or when coming back from single user mode.
echo 'Retriggering failed uevents:'
udevtrigger --verbose --retry-failed && udevsettle --timeout="$UDEV_SETTLE_TIMEOUT"

# Turn on process accounting. To enable process accounting, make sure the
# option for BSD process accounting is enabled in your kernel, and then
# create the file /var/log/pacct (touch /var/log/pacct). By default, process
# accounting is not enabled (since /var/log/pacct does not exist). This is
# because the log file can get VERY large.
if [ -r /var/log/pacct ] && type -P accton &> /dev/null; then
	rc_cmd 'Enabling process accounting'  accton /var/log/pacct
	chmod 640 /var/log/pacct
fi

# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' and/or 'grpquota'
# to the appropriate partitions as listed in /etc/fstab. Here's an example:
#
#     /dev/hda2      /home      ext3     defaults,usrquota      1   1
#
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
#
#     touch /home/aquota.user /home/aquota.group
#     chmod 600 /home/aquota.user /home/aquota.group
#
# Then, reboot to activate the system. To edit user quotas,
# use 'edquota'. See 'man edquota'. The official Quota Mini-HOWTO
# has lots of useful information too.
#
# Check quotas and then turn quota system on.
if egrep -wq '(usr|grp)quota' /etc/fstab ; then
	rc_cmd "Checking filesystem quotas"    quotacheck -avugm
	rc_cmd "Activating filesystem quotas"  quotaon -avug
fi

# Start the services.
rc_services_start SERVICES "${SERVICES[@]}"

# End of rc.M
